<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class Sm00006001TabelaPrecoServicoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getTabelaPrecoServicoGrid()
    {
        $sql = "SELECT FCT_PRECBASESERV.CDPRECBASESERV,
                        FCT_PRECBASESERV.DSPRECBASESERV,
                        FCT_PRECBASESERV.NRORG,
                        FCT_PRECBASESERV.DTINCLUSAO,
                        FCT_PRECBASESERV.DTULTATU,
                        FCT_PRECBASESERV.NRORGINCLUSAO,
                        FCT_PRECBASESERV.CDOPERINCLUSAO,
                        OPINC.NMOPERADOR AS NMOPERINCLUSAO,
                        FCT_PRECBASESERV.NRORGULTATU,
                        FCT_PRECBASESERV.CDOPERULTATU,
                        OPATU.NMOPERADOR AS NMOPERULTATU,
                        FCT_PRECBASESERV.IDATIVO,
                        FCT_PRECBASESERV.NRMOEDA,
                        MD.NMMOEDA
                FROM FCT_PRECBASESERV
                LEFT JOIN OPERADOR OPINC ON FCT_PRECBASESERV.CDOPERINCLUSAO = OPINC.CDOPERADOR
                AND FCT_PRECBASESERV.NRORG = OPINC.NRORG
                LEFT JOIN OPERADOR OPATU ON FCT_PRECBASESERV.CDOPERULTATU = OPATU.CDOPERADOR
                AND FCT_PRECBASESERV.NRORG = OPATU.NRORG
                LEFT JOIN FCT_MOEDA MD ON FCT_PRECBASESERV.NRMOEDA = MD.NRMOEDA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getServicosTabelaPreco($params)
    {
        $sql = "SELECT FCT_ITPRECBASESERV.NRSEQITPRECBSERV,
                        FCT_ITPRECBASESERV.CDPRECBASESERV,
                        TO_CHAR(FCT_ITPRECBASESERV.DTINIPBSERV, 'DD/MM/YYYY') AS DTINIPBSERV,
                        FCT_ITPRECBASESERV.CDTPMEDIDASERV,
                        FCT_TIPOMEDIDASERV.DSTPMEDIDASERV,
                        FCT_ITPRECBASESERV.CDSERVORCA,
                        FCT_SERVICOORCA.NMSERVORCA,
                        FCT_ITPRECBASESERV.VRPRECO,
                        TO_CHAR(FCT_ITPRECBASESERV.DTFIMVALPBSERV, 'DD/MM/YYYY') AS DTFIMVALPBSERV,
                        FCT_ITPRECBASESERV.CDFILIAL,
                        FCT_ITPRECBASESERV.NRORG,
                        FCT_ITPRECBASESERV.DTINCLUSAO,
                        FCT_ITPRECBASESERV.DTULTATU,
                        FCT_ITPRECBASESERV.NRORGINCLUSAO,
                        FCT_ITPRECBASESERV.CDOPERINCLUSAO,
                        OPINC.NMOPERADOR AS NMOPERINCLUSAO,
                        FCT_ITPRECBASESERV.NRORGULTATU,
                        FCT_ITPRECBASESERV.CDOPERULTATU,
                        OPATU.NMOPERADOR AS NMOPERULTATU,
                        FCT_ITPRECBASESERV.IDATIVO
                FROM FCT_ITPRECBASESERV
                JOIN FCT_SERVICOORCA ON FCT_ITPRECBASESERV.CDSERVORCA = FCT_SERVICOORCA.CDSERVORCA
                AND FCT_ITPRECBASESERV.NRORG = FCT_SERVICOORCA.NRORG
                JOIN FCT_TIPOMEDIDASERV ON FCT_ITPRECBASESERV.CDTPMEDIDASERV = FCT_TIPOMEDIDASERV.CDTPMEDIDASERV
                AND FCT_ITPRECBASESERV.NRORG = FCT_TIPOMEDIDASERV.NRORG
                LEFT JOIN OPERADOR OPINC ON FCT_ITPRECBASESERV.CDOPERINCLUSAO = OPINC.CDOPERADOR
                AND FCT_ITPRECBASESERV.NRORG = OPINC.NRORG
                LEFT JOIN OPERADOR OPATU ON FCT_ITPRECBASESERV.CDOPERULTATU = OPATU.CDOPERADOR
                AND FCT_ITPRECBASESERV.NRORG = OPATU.NRORG
                WHERE FCT_ITPRECBASESERV.CDPRECBASESERV = :CDPRECBASESERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function insertTabelaPreco(array $params)
    {

        $sql = "INSERT INTO FCT_PRECBASESERV (
            CDPRECBASESERV,     DSPRECBASESERV,     NRORG,
            DTINCLUSAO,         NRORGINCLUSAO,      CDOPERINCLUSAO,      
            IDATIVO,            NRMOEDA
        )
        VALUES (
            :CDPRECBASESERV,    :DSPRECBASESERV,     :NRORG,
            SYSDATE,            :NRORGINCLUSAO,      :CDOPERINCLUSAO,    
            :IDATIVO,           :NRMOEDA
        )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateTabelaPreco($params)
    {
        $sql = "UPDATE FCT_PRECBASESERV 
        SET DSPRECBASESERV = :DSPRECBASESERV, 
        NRORG = :NRORG,
        NRORGULTATU = :NRORGULTATU,
        CDOPERULTATU = :CDOPERULTATU,
        IDATIVO = :IDATIVO,
        NRMOEDA = :NRMOEDA
        WHERE CDPRECBASESERV = :CDPRECBASESERV";
        $this->connection->executeStatement($sql, $params);
    }

    public function deleteTabelaPrecoServico($params)
    {
        $sql = "DELETE FROM FCT_PRECBASESERV WHERE CDPRECBASESERV = :CDPRECBASESERV";
        $this->connection->executeStatement($sql, $params);
    }

    public function insertTabPrecos(array $params)
    {

        $sql = "INSERT INTO FCT_PRECBASESERV (
            CDPRECBASESERV,         DSPRECBASESERV,         NRMOEDA,
            NRORG,                  CDOPERINCLUSAO,         DTINCLUSAO
        )
        VALUES (
            :CDPRECBASESERV,        :DSPRECBASESERV,        :NRMOEDA,
            :NRORG,                 :CDOPERINCLUSAO,        SYSDATE
        )";

        $this->connection->executeStatement($sql, $params);
    }

    public function getDadosServico($params)
    {

        $sql = "SELECT FCT_ITPRECBASESERV.NRSEQITPRECBSERV, FCT_ITPRECBASESERV.CDPRECBASESERV, TO_CHAR(FCT_ITPRECBASESERV.DTINIPBSERV, 'DD/MM/YYYY') AS DTINIPBSERV, 
        FCT_ITPRECBASESERV.CDTPMEDIDASERV,FCT_ITPRECBASESERV.CDSERVORCA, FCT_ITPRECBASESERV.VRPRECO, TO_CHAR(FCT_ITPRECBASESERV.DTFIMVALPBSERV, 'DD/MM/YYYY') AS DTFIMVALPBSERV, 
        FCT_ITPRECBASESERV.CDFILIAL, FCT_ITPRECBASESERV.NRORG, FCT_ITPRECBASESERV.DTINCLUSAO, FCT_ITPRECBASESERV.DTULTATU, 
        FCT_ITPRECBASESERV.NRORGINCLUSAO, FCT_ITPRECBASESERV.CDOPERINCLUSAO, FCT_ITPRECBASESERV.NRORGULTATU, FCT_ITPRECBASESERV.CDOPERULTATU,FCT_ITPRECBASESERV.IDATIVO 
            FROM FCT_ITPRECBASESERV 
            WHERE FCT_ITPRECBASESERV.CDPRECBASESERV = :CDPRECBASESERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function insertItPrecBaseServ(array $params)
    {
        $sql = "INSERT INTO FCT_ITPRECBASESERV (
            NRSEQITPRECBSERV,       CDPRECBASESERV,         DTINIPBSERV,
            CDTPMEDIDASERV,         CDSERVORCA,             VRPRECO,
            DTFIMVALPBSERV,         CDFILIAL,               NRORG,
            DTINCLUSAO,             DTULTATU,               NRORGINCLUSAO,
            CDOPERINCLUSAO,         NRORGULTATU,            CDOPERULTATU,
            IDATIVO            
        )
        VALUES (
            :NRSEQITPRECBSERV,       :CDPRECBASESERV,         :DTINIPBSERV,
            :CDTPMEDIDASERV,         :CDSERVORCA,             :VRPRECO,
            :DTFIMVALPBSERV,         :CDFILIAL,               :NRORG,
            :DTINCLUSAO,             :DTULTATU,               :NRORGINCLUSAO,
            :CDOPERINCLUSAO,         :NRORGULTATU,            :CDOPERULTATU,
            :IDATIVO           
        )";
        $this->connection->executeStatement($sql, $params);
    }

    public function getDadosVariacao($params)
    {
        $sql = "SELECT FCT_VARIACAOPRECBASESERV.NRVARIACAOPRECBASESERV, FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV, FCT_VARIACAOPRECBASESERV.CDTPMEDIDASERV, MEDIDAFIXA.DSTPMEDIDASERV AS NMMEDIDAFIXA, 
        TO_CHAR(FCT_VARIACAOPRECBASESERV.DTINIPBSERV, 'DD/MM/YYYY') AS DTINIPBSERV, FCT_VARIACAOPRECBASESERV.QTMEDIDAINIVARIACAO, FCT_VARIACAOPRECBASESERV.QTMEDIDAFIMVARIACAO,
        FCT_VARIACAOPRECBASESERV.VRPRECOVARIACAO, FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL, MEDIDAVAR.DSTPMEDIDASERV AS NMMEDIDAVAR, FCT_VARIACAOPRECBASESERV.IDMULTIPVARIACAO, 
        FCT_VARIACAOPRECBASESERV.NRORG, FCT_VARIACAOPRECBASESERV.IDATIVO, FCT_VARIACAOPRECBASESERV.DTINCLUSAO, FCT_VARIACAOPRECBASESERV.DTULTATU, FCT_VARIACAOPRECBASESERV.QTFRANQUIA,
        FCT_VARIACAOPRECBASESERV.NRORGINCLUSAO, FCT_VARIACAOPRECBASESERV.CDOPERINCLUSAO, FCT_VARIACAOPRECBASESERV.NRORGULTATU, FCT_VARIACAOPRECBASESERV.CDOPERULTATU
            FROM FCT_VARIACAOPRECBASESERV 
            JOIN FCT_ITPRECBASESERV ON FCT_ITPRECBASESERV.NRSEQITPRECBSERV = FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV 
            LEFT JOIN FCT_TIPOMEDIDASERV MEDIDAFIXA ON MEDIDAFIXA.CDTPMEDIDASERV = FCT_VARIACAOPRECBASESERV.CDTPMEDIDASERV 
            LEFT JOIN FCT_TIPOMEDIDASERV MEDIDAVAR ON MEDIDAVAR.CDTPMEDIDASERV = FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL
            WHERE FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV = :NRSEQITPRECBSERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function insertVariacao(array $params)
    {
        $sql = "INSERT INTO FCT_VARIACAOPRECBASESERV (
            NRVARIACAOPRECBASESERV, NRSEQITPRECBSERV,       CDTPMEDIDASERV,
            DTINIPBSERV,            QTMEDIDAINIVARIACAO,    QTMEDIDAFIMVARIACAO,
            VRPRECOVARIACAO,        CDTPMEDIDAVARIAVEL,     IDMULTIPVARIACAO,
            NRORG,                  IDATIVO,                DTINCLUSAO,
            DTULTATU,               QTFRANQUIA,             NRORGINCLUSAO,
            CDOPERINCLUSAO,         NRORGULTATU,            CDOPERULTATU
        )
        VALUES (
            :NRVARIACAOPRECBASESERV, :NRSEQITPRECBSERV,       :CDTPMEDIDASERV,
            :DTINIPBSERV,            :QTMEDIDAINIVARIACAO,    :QTMEDIDAFIMVARIACAO,
            :VRPRECOVARIACAO,        :CDTPMEDIDAVARIAVEL,     :IDMULTIPVARIACAO,
            :NRORG,                  :IDATIVO,                :DTINCLUSAO,
            :DTULTATU,               :QTFRANQUIA,             :NRORGINCLUSAO,
            :CDOPERINCLUSAO,         :NRORGULTATU,            :CDOPERULTATU          
        )";
        $this->connection->executeStatement($sql, $params);
    }

    public function validaServicoTabela($params)
    {
        $sql = "SELECT COUNT(*) AS VALIDASERV
                  FROM FCT_ITPRECBASESERV
                 WHERE CDSERVORCA IN (".$params['CDSERVORCA'].")
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV
                   AND CDPRECBASESERV = :CDPRECBASESERV
                   AND NRORG = :NRORG";
        unset($params['CDSERVORCA']);
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function insertServicoTabelaPreco(array $params)
    {

        $sql = "INSERT INTO FCT_ITPRECBASESERV (
            NRSEQITPRECBSERV,     CDPRECBASESERV,       DTINIPBSERV,
            CDTPMEDIDASERV,       CDSERVORCA,           VRPRECO,      
            DTFIMVALPBSERV,       NRORG,                DTINCLUSAO,
            NRORGINCLUSAO,        CDOPERINCLUSAO,       IDATIVO
        )
        VALUES (
            :NRSEQITPRECBSERV,    :CDPRECBASESERV,      :DTINIPBSERV,
            :CDTPMEDIDASERV,      :CDSERVORCA,          :VRPRECO,    
            :DTFIMVALPBSERV,      :NRORG,               SYSDATE,
            :NRORGINCLUSAO,       :CDOPERINCLUSAO,      :IDATIVO
        )";

        $this->connection->executeStatement($sql, $params);
    }

    public function updateServicoTabelaPreco($params)
    {
        $sql = "UPDATE FCT_ITPRECBASESERV 
        SET CDPRECBASESERV  = :CDPRECBASESERV, 
        DTINIPBSERV         = :DTINIPBSERV,
        CDTPMEDIDASERV      = :CDTPMEDIDASERV,
        CDSERVORCA          = :CDSERVORCA,
        VRPRECO             = :VRPRECO,
        DTFIMVALPBSERV      = :DTFIMVALPBSERV,
        NRORG               = :NRORG,
        NRORGULTATU         = :NRORGULTATU,
        CDOPERULTATU        = :CDOPERULTATU,
        IDATIVO             = :IDATIVO,
        DTINCLUSAO          = SYSDATE
        WHERE NRSEQITPRECBSERV = :NRSEQITPRECBSERV";
        $this->connection->executeStatement($sql, $params);
    }

    public function deleteServicosTabelaPrecoServico($params)
    {
        $sql = "DELETE FROM FCT_ITPRECBASESERV WHERE NRSEQITPRECBSERV = :NRSEQITPRECBSERV";
        $this->connection->executeStatement($sql, $params);
    }

    public function getMedidaVariavelTabelaPreco($params)
    {
        $sql = "SELECT DISTINCT FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV,
                        FCT_VARIACAOPRECBASESERV.CDTPMEDIDASERV,
                        MEDIDAFIXA.DSTPMEDIDASERV AS NMMEDIDAFIXA,
                        FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL,
                        MEDIDAVAR.DSTPMEDIDASERV AS NMMEDIDAVAR,
                        FCT_VARIACAOPRECBASESERV.IDMULTIPVARIACAO,
                        FCT_VARIACAOPRECBASESERV.NRORG,
                        FCT_VARIACAOPRECBASESERV.IDATIVO,
                        FCT_VARIACAOPRECBASESERV.QTFRANQUIA,
                        FCT_VARIACAOPRECBASESERV.NRVARIACAOPRECBASESERV
                FROM FCT_VARIACAOPRECBASESERV
                JOIN FCT_ITPRECBASESERV ON FCT_ITPRECBASESERV.NRSEQITPRECBSERV = FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV
                AND FCT_ITPRECBASESERV.NRORG = FCT_VARIACAOPRECBASESERV.NRORG
                LEFT JOIN FCT_TIPOMEDIDASERV MEDIDAFIXA ON MEDIDAFIXA.CDTPMEDIDASERV = FCT_VARIACAOPRECBASESERV.CDTPMEDIDASERV
                AND MEDIDAFIXA.NRORG = FCT_VARIACAOPRECBASESERV.NRORG
                LEFT JOIN FCT_TIPOMEDIDASERV MEDIDAVAR ON MEDIDAVAR.CDTPMEDIDASERV = FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL
                AND MEDIDAVAR.NRORG = FCT_VARIACAOPRECBASESERV.NRORG
                WHERE FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV = :NRSEQITPRECBSERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function validaFranquiaFaixa($params)
    {
        
        $sql = "SELECT COUNT(*) AS FAIXAS
                  FROM FCT_VARIACAOPRECBASESERV
                 WHERE NRORG = :NRORG
                   AND NRSEQITPRECBSERV = :NRSEQITPRECBSERV
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV 
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                   AND ((:QTFRANQUIA BETWEEN QTMEDIDAINIVARIACAO AND QTMEDIDAFIMVARIACAO) 
                         OR (QTMEDIDAFIMVARIACAO < :QTFRANQUIA))";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function sinconizaMedidaVariavel($params)
    {
        $sql = "SELECT CDTPMEDIDASERV, CDTPMEDIDAVARIAVEL, QTMEDIDAINIVARIACAO,
                      QTMEDIDAFIMVARIACAO, VRPERCVARIACAO
                 FROM FCT_VARIACAOTIPOMEDIDA
                WHERE CDTPMEDIDASERV = :CDTPMEDIDASERV 
                  AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                  AND NRORG = :NRORG
                ORDER BY QTMEDIDAINIVARIACAO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function insereVariacaoPreco($params)
    {
        $sql = "INSERT INTO FCT_VARIACAOPRECBASESERV(
                    NRVARIACAOPRECBASESERV, NRSEQITPRECBSERV, DTINIPBSERV, CDTPMEDIDASERV, CDTPMEDIDAVARIAVEL, 
                    QTMEDIDAINIVARIACAO, QTMEDIDAFIMVARIACAO, VRPRECOVARIACAO, DTFIMVALPBSERV, CDFILIAL, IDMULTIPVARIACAO, 
                    QTFRANQUIA, NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO
                )
                VALUES (
                    :NRVARIACAOPRECBASESERV, :NRSEQITPRECBSERV, SYSDATE, :CDTPMEDIDASERV, :CDTPMEDIDAVARIAVEL,
                    :QTMEDIDAINIVARIACAO, :QTMEDIDAFIMVARIACAO, :VRPRECOVARIACAO, NULL, NULL, :IDMULTIPVARIACAO,
                    :QTFRANQUIA, :NRORG, SYSDATE, :NRORG, :OPERADOR, 'S'  
                )";
        $this->connection->executeStatement($sql, $params);
    }

    public function updateVariacao($params)
    {
        $sql = "UPDATE FCT_VARIACAOPRECBASESERV
                   SET IDMULTIPVARIACAO = :IDMULTIPVARIACAO,
                       QTFRANQUIA = :QTFRANQUIA,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRVARIACAOPRECBASESERV = :NRVARIACAOPRECBASESERV
                   AND NRSEQITPRECBSERV = :NRSEQITPRECBSERV
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV 
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL";
        
        $this->connection->executeStatement($sql, $params);
    }

    public function deleteServicosTabelaPrecoMedidaVariavel($params)
    {
        $sql = "DELETE FROM FCT_VARIACAOPRECBASESERV WHERE NRVARIACAOPRECBASESERV = :NRVARIACAOPRECBASESERV";
        $this->connection->executeStatement($sql, $params);
    }

    public function getVariacaoPrecoTabelaPreco($params)
    {
        $sql = "SELECT FCT_VARIACAOPRECBASESERV.NRVARIACAOPRECBASESERV,
                        FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV,
                        TO_CHAR(FCT_VARIACAOPRECBASESERV.DTINIPBSERV, 'DD/MM/YYYY') AS DTINIPBSERV,
                        FCT_VARIACAOPRECBASESERV.CDTPMEDIDASERV,
                        MEDIDAFIXA.DSTPMEDIDASERV AS NMMEDIDAFIXA,
                        FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL,
                        MEDIDAVAR.DSTPMEDIDASERV AS NMMEDIDAVAR,
                        FCT_VARIACAOPRECBASESERV.QTMEDIDAINIVARIACAO,
                        FCT_VARIACAOPRECBASESERV.QTMEDIDAFIMVARIACAO,
                        FCT_VARIACAOPRECBASESERV.VRPRECOVARIACAO,
                        TO_CHAR(FCT_VARIACAOPRECBASESERV.DTFIMVALPBSERV, 'DD/MM/YYYY') AS DTFIMVALPBSERV,
                        FCT_VARIACAOPRECBASESERV.IDMULTIPVARIACAO,
                        FCT_VARIACAOPRECBASESERV.CDFILIAL,
                        FILIAL.NMFILIAL,
                        FCT_VARIACAOPRECBASESERV.NRORG,
                        FCT_VARIACAOPRECBASESERV.DTINCLUSAO,
                        FCT_VARIACAOPRECBASESERV.DTULTATU,
                        FCT_VARIACAOPRECBASESERV.NRORGINCLUSAO,
                        FCT_VARIACAOPRECBASESERV.CDOPERINCLUSAO,
                        FCT_VARIACAOPRECBASESERV.NRORGULTATU,
                        FCT_VARIACAOPRECBASESERV.CDOPERULTATU,
                        FCT_VARIACAOPRECBASESERV.IDATIVO,
                        FCT_VARIACAOPRECBASESERV.QTFRANQUIA
                FROM FCT_VARIACAOPRECBASESERV
                JOIN FCT_ITPRECBASESERV ON FCT_ITPRECBASESERV.NRSEQITPRECBSERV = FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV
                AND FCT_ITPRECBASESERV.NRORG = FCT_VARIACAOPRECBASESERV.NRORG
                LEFT JOIN FCT_TIPOMEDIDASERV MEDIDAFIXA ON MEDIDAFIXA.CDTPMEDIDASERV = FCT_VARIACAOPRECBASESERV.CDTPMEDIDASERV
                AND MEDIDAFIXA.NRORG = FCT_VARIACAOPRECBASESERV.NRORG
                LEFT JOIN FCT_TIPOMEDIDASERV MEDIDAVAR ON MEDIDAVAR.CDTPMEDIDASERV = FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL
                AND MEDIDAVAR.NRORG = FCT_VARIACAOPRECBASESERV.NRORG
                LEFT JOIN FILIAL ON FILIAL.CDFILIAL = FCT_VARIACAOPRECBASESERV.CDFILIAL
                AND FILIAL.NRORG = FCT_VARIACAOPRECBASESERV.NRORG
                WHERE FCT_VARIACAOPRECBASESERV.NRVARIACAOPRECBASESERV = :NRVARIACAOPRECBASESERV";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function validaTipoMedidaVariavel($params)
    {
        $sql = "SELECT CDTPMEDIDAVARIAVEL, QTMEDIDAINIVARIACAO, QTMEDIDAFIMVARIACAO
                  FROM FCT_VARIACAOPRECBASESERV
                 WHERE NRSEQITPRECBSERV = :NRSEQITPRECBSERV 
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                   AND NRVARIACAOPRECBASESERV <> NVL(:NRVARIACAOPRECBASESERV, -1) 
                   AND NRORG = :NRORG";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }
}
