<?php

namespace SM\Traits;

use Doctrine\ORM\EntityManager;

trait TQuery {
    use \Teknisa\Model\Traits\TQuery;

    public function createAndExecuteQueryAndBuildResponseData(EntityManager $entityManager, $query, $params = [],
                                                              $types = [], $page = null, $limit = null, $order = null, $dynamicFilter = null)
    {
        if ($dynamicFilter) {
            $finalQuery = $this->getFinalQuery($query, $page, $limit, $order, null, null, $dynamicFilter, null, false);
        }
        else {
            $finalQuery = $this->getFinalQuery($query, $page, $limit, $order);
        }
        return $this->executeQueryAndBuildResponseData($entityManager, $finalQuery, $params, $types, $page, $limit);
    }

    /**
     * @param $query
     * @param null $page
     * @param null $limit
     * @param null $order
     * @param null $search
     * @param null $searchIn
     * @return string
     */
    public function getFinalQuery($query, $page = null, $limit = null, $order = null, $search = null, $searchIn = null,
                                  $dynamicFilter = null, $find = null, $base64Decode = true)
    {
        $page = $page ? $page : $this->getPage();
        $limit = $limit ? $limit : $this->getLimit();
        $order = $order ? $order : $this->getOrder();
        $search = $search ? $search : $this->getSearch();
        $searchIn = $searchIn ? $searchIn : $this->getSearchIn();
        $find = $find ? $find : $this->getFind();
        $dynamicFilter = $dynamicFilter ? $dynamicFilter : $this->getDynamicFilter();

        $conditions = $search ? $this->createSearch($search, $searchIn) : '';
        $conditions .= $this->createFind($find, $conditions);
        $conditions .= $dynamicFilter ? $this->createDynamicFilter($dynamicFilter, $conditions, $base64Decode) : '';

        $pagination = $this->createPagination($page, $limit);
        $order = empty($order) ? '' : $this->createOrderBy($order);

        return $this->buildQuery($query, $pagination, $order, $conditions);
    }
}