/* Tabela PRECOUTI: Parametros de Preco */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela PRECOUTI */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela PRECOUTI,
             utilizando a tabela Geral de Logs de Operaes */

IF EXISTS(SELECT *
          FROM SYSOBJECTS O, SYSUSERS U
          WHERE O.NAME = 'LOG_PED_PRECOUTI' AND
                TYPE   = 'TR'              AND
                U.UID  = O.UID             AND
                U.NAME = USER)

DROP TRIGGER LOG_PED_PRECOUTI
GO
CREATE TRIGGER LOG_PED_PRECOUTI
ON PRECOUTI
FOR UPDATE,INSERT, DELETE
AS
BEGIN
  DECLARE @V_USUARIO             VARCHAR(40);
  DECLARE @V_TIPO                VARCHAR(1);
  DECLARE @V_TPMOVI              VARCHAR(1);
  DECLARE @V_ITPESQ              VARCHAR(40);
  DECLARE @V_DESC                VARCHAR(500);
  DECLARE @V_CDFILLOGOPER        VARCHAR(4);
  DECLARE @V_DSREMOTEADDR        VARCHAR(15);
  DECLARE @V_DSREMOTEHOST        VARCHAR(15);
  DECLARE @V_DSSERVERRDM         VARCHAR(20);
  DECLARE @V_DSSERVMETHOD        VARCHAR(30);
  DECLARE @V_DSREMOTEOPER        VARCHAR(12);
  DECLARE @V_DTOPER              DATETIME;

  DECLARE @V_NRSEQPREUTI_NEW     VARCHAR(10);
  DECLARE @V_CDEMPRESA_NEW       VARCHAR(02);
  DECLARE @V_CDFILIAL_NEW        VARCHAR(04);
  DECLARE @V_CDMODPGTO_NEW       VARCHAR(05);
  DECLARE @V_CDPRECOBASE_NEW     VARCHAR(02);
  DECLARE @V_VRPEADPBASE_NEW     NUMERIC(15,5);

  DECLARE @V_NRSEQPREUTI_OLD     VARCHAR(10);
  DECLARE @V_CDEMPRESA_OLD       VARCHAR(02);
  DECLARE @V_CDFILIAL_OLD        VARCHAR(04);
  DECLARE @V_CDMODPGTO_OLD       VARCHAR(05);
  DECLARE @V_CDPRECOBASE_OLD     VARCHAR(02);
  DECLARE @V_VRPEADPBASE_OLD     NUMERIC(15,5);


   SET @V_TIPO = '0';
   SET @V_DESC = '';
   SET @V_CDFILLOGOPER = '';
   SET @V_USUARIO = '-';


   DECLARE C_CURSOR_NF CURSOR FOR
      SELECT
         'D' IDCOMANDO,
         NULL, NULL, NULL, NULL, NULL, NULL,
         NRSEQPREUTI,
         CDEMPRESA,
         CDFILIAL,
         CDMODPGTO,
         CDPRECOBASE,
         VRPEADPBASE
      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)

      UNION ALL

      SELECT
         'U' IDCOMANDO,
         INSERTED.NRSEQPREUTI,
         INSERTED.CDEMPRESA,
         INSERTED.CDFILIAL,
         INSERTED.CDMODPGTO,
         INSERTED.CDPRECOBASE,
         INSERTED.VRPEADPBASE,
         DELETED.NRSEQPREUTI,
         DELETED.CDEMPRESA,
         DELETED.CDFILIAL,
         DELETED.CDMODPGTO,
         DELETED.CDPRECOBASE,
         DELETED.VRPEADPBASE
      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.NRSEQPREUTI = DELETED.NRSEQPREUTI

      UNION ALL

      SELECT
         'I' IDCOMANDO,
         INSERTED.NRSEQPREUTI,
         INSERTED.CDEMPRESA,
         INSERTED.CDFILIAL,
         INSERTED.CDMODPGTO,
         INSERTED.CDPRECOBASE,
         INSERTED.VRPEADPBASE,

         NULL, NULL, NULL, NULL, NULL, NULL
      FROM
         INSERTED
      WHERE
         0 = (SELECT COUNT(*) FROM DELETED)

   OPEN C_CURSOR_NF;
   FETCH NEXT FROM C_CURSOR_NF   INTO @V_TIPO, @V_NRSEQPREUTI_NEW, @V_CDEMPRESA_NEW, @V_CDFILIAL_NEW,
                                      @V_CDMODPGTO_NEW, @V_CDPRECOBASE_NEW, @V_VRPEADPBASE_NEW,

                                      @V_NRSEQPREUTI_OLD, @V_CDEMPRESA_OLD, @V_CDFILIAL_OLD,
                                      @V_CDMODPGTO_OLD,@V_CDPRECOBASE_OLD, @V_VRPEADPBASE_OLD;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      IF @V_TIPO = 'D' BEGIN
         IF @V_CDEMPRESA_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + 'Empr=' + @V_CDEMPRESA_OLD;
         END;

         IF @V_CDFILIAL_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + ' Filial=' + @V_CDFILIAL_OLD;
         END;

         IF @V_CDMODPGTO_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + ' Mod.Pag=' + @V_CDMODPGTO_OLD;
         END;

         IF @V_CDPRECOBASE_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + ' Pr.Base=' + @V_CDPRECOBASE_OLD;
         END;

         IF @V_VRPEADPBASE_OLD IS NOT NULL BEGIN
            SET @V_DESC = @V_DESC + ' VrPeAd=' + CONVERT(VARCHAR,@V_VRPEADPBASE_OLD);
         END;


         SET @V_TPMOVI       = '3';
         SET @V_ITPESQ       = @V_NRSEQPREUTI_OLD;
         SET @V_CDFILLOGOPER = @V_CDFILIAL_OLD;
      END
      ELSE BEGIN
         IF @V_TIPO = 'U' BEGIN
            IF (@V_CDEMPRESA_OLD   <> @V_CDEMPRESA_NEW)   OR
               (@V_CDFILIAL_OLD    <> @V_CDFILIAL_NEW)    OR
               (@V_CDMODPGTO_OLD   <> @V_CDMODPGTO_NEW)   OR
               (@V_CDPRECOBASE_OLD <> @V_CDPRECOBASE_NEW) OR
               (@V_VRPEADPBASE_OLD <> @V_VRPEADPBASE_NEW) BEGIN

               SET @V_TPMOVI       = '2';
               SET @V_ITPESQ       = @V_NRSEQPREUTI_OLD;
               SET @V_CDFILLOGOPER = @V_CDFILIAL_OLD;
            END;
         END
         ELSE BEGIN
            SET @V_TPMOVI        = '1';
            SET @V_ITPESQ        = @V_NRSEQPREUTI_NEW;
            SET @V_CDFILLOGOPER  = @V_CDFILIAL_NEW;
         END;

         IF ISNULL(@V_CDEMPRESA_NEW, '!') <> ISNULL(@V_CDEMPRESA_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + 'Empr=' + @V_CDEMPRESA_NEW;
         END;

         IF ISNULL(@V_CDFILIAL_NEW, '!') <> ISNULL(@V_CDFILIAL_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + ' Filial=' + @V_CDFILIAL_NEW;
         END;

         IF ISNULL(@V_CDMODPGTO_NEW, '!') <> ISNULL(@V_CDMODPGTO_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + ' Mod.Pag=' + @V_CDMODPGTO_NEW;
         END;

         IF ISNULL(@V_CDPRECOBASE_NEW, '!') <> ISNULL(@V_CDPRECOBASE_OLD, '!') BEGIN
            SET @V_DESC = @V_DESC + ' Pr.Base=' + @V_CDPRECOBASE_NEW;
         END;

         IF (@V_VRPEADPBASE_NEW IS NOT NULL) AND (@V_VRPEADPBASE_NEW <> @V_VRPEADPBASE_OLD) BEGIN
            SET @V_DESC = @V_DESC + ' VrPeAd=' + CONVERT(VARCHAR,@V_VRPEADPBASE_NEW);
         END;

      END;

      IF @V_TPMOVI <> '0' BEGIN
         EXEC NMUSUARIO  @V_USUARIO;
         EXEC WEBTUNNING @V_DSREMOTEADDR,
                         @V_DSREMOTEHOST,
                         @V_DSSERVERRDM,
                         @V_DSSERVMETHOD,
                         @V_DSREMOTEOPER;
         IF NOT @V_DESC IS NULL BEGIN
            IF NOT @V_USUARIO IS NULL BEGIN
               SET @V_DTOPER = GETDATE();

               INSERT INTO LOGOPERA
                  (NMTABELA,
                   DTOPERACAO,
                   NMRESPOPER,
                   IDTIPOOPER,
                   CDPESQITEM,
                   DSOPERACAO,
                   CDFILLOGOPER,
                   DSRDMUSUOPER,
                   DSENDUSUOPER,
                   DSNMUSUOPER,
                   DSMETUSUOPER,
                   CDORESPOPER)
               VALUES
                  ('PRECOUTI',
                   @V_DTOPER,
                   @V_USUARIO,
                   @V_TPMOVI,
                   @V_ITPESQ,
                   SUBSTRING(@V_DESC,1,300),
                   @V_CDFILLOGOPER,
                   @V_DSSERVERRDM,
                   @V_DSREMOTEADDR,
                   @V_DSREMOTEHOST,
                   @V_DSSERVMETHOD,
                   @V_DSREMOTEOPER);
            END;
         END;
      END;
      FETCH NEXT FROM C_CURSOR_NF   INTO @V_TIPO, @V_NRSEQPREUTI_NEW, @V_CDEMPRESA_NEW, @V_CDFILIAL_NEW,
                                      @V_CDMODPGTO_NEW, @V_CDPRECOBASE_NEW, @V_VRPEADPBASE_NEW,

                                      @V_NRSEQPREUTI_OLD, @V_CDEMPRESA_OLD, @V_CDFILIAL_OLD,
                                      @V_CDMODPGTO_OLD,@V_CDPRECOBASE_OLD, @V_VRPEADPBASE_OLD;

   END;
   CLOSE C_CURSOR_NF;
   DEALLOCATE C_CURSOR_NF;
END;
GO


-- VERSAO --
EXEC ATUVEROBJ 'LOG_PED_PRECOUTI','0.00.000';
GO
