import { Utilities } from '@/util/Utilities';
import {
    Form, Modal, ModalService, Select, Date, LoadingService, TextInput, DialogService, DateRange,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import moment from 'moment';

export class AgendaServicosController {
    private LogModal!: Modal;

    private FilterModal!: Modal;

    private ZerarModal!: Modal;

    private EditarModal!: Modal;

    public campoModal: any = {};

    public currentRow: any = {};

    public eventFilter({ event }: any) {
        event.preventDefault();
        this.abrirModalFilterClick();
    }

    public async abrirModalFilterClick() {
        await this.exibirModalFilter();
        Metadata.getInstance<Select>('formFilterAgendaServicos-CDCLIENTE').value = this.campoModal.cdcliente;
        Metadata.getInstance<Select>('formFilterAgendaServicos-NRPROPOSFAS').value = this.campoModal.nrproposfas;
        Metadata.getInstance<Select>('contratos-sm').value = this.campoModal.contrato;
        Metadata.getInstance<DateRange>('periodo-data-agendamento').value = this.campoModal.dataAgendamento;
    }

    public async abrirModalFilter() {
        await this.exibirModalFilter();
    }

    public async exibirModalFilter() {
        this.FilterModal = await ModalService.createFromJson('agendaServicos/modal/filter_modal_agenda_servicos', true);
        this.FilterModal.show();
    }

    public fecharModalFilter() {
        this.FilterModal.hide();
        this.FilterModal?.destroy();
    }

    public setFilterCampoProposta({ component }: any) {
        const proposta = Metadata.getInstance<Select>('formFilterAgendaServicos-NRPROPOSFAS');

        if (component.value) {
            proposta.datasource.setFilter({
                CDCLIENTE: component.value,
            });
            proposta.disabled = false;
        } else {
            proposta.disabled = true;
            proposta.value = null;
        }
    }

    public filterGrid() {
        const cdcliente = Metadata.getInstance<Select>('formFilterAgendaServicos-CDCLIENTE').value;
        const nrproposfas = Metadata.getInstance<Select>('formFilterAgendaServicos-NRPROPOSFAS');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-agenda-servicos');
        const contrato = Metadata.getInstance<Select>('contratos-sm').value;
        const dataAgendamento = Metadata.getInstance<DateRange>('periodo-data-agendamento').value;

        this.campoModal = {
            cdcliente,
            nrproposfas,
            contrato,
            dataAgendamento,
        };

        grid.datasource.setFilter({
            CDCLIENTE: cdcliente,
            NRPROPOSFAS: nrproposfas.value,
            NRVERPROPFAS: (nrproposfas.value === null) ? null : nrproposfas.selectValue.NRVERPROPFAS,
            NRSEQCONTRATO: contrato,
            USR_DTAGENDZERASALDO: dataAgendamento,
        });
        this.fecharModalFilter();
    }

    public async abrirModalZerar({ row }: any) {
        await this.exibirModalZerar();
        Metadata.getInstance<Date>('formZerarAgendaServicos-USR_DTAGENDZERASALDO').value = moment().format('DD/MM/YYYY');
        if (row !== undefined) {
            this.currentRow = {
                USR_QTSERVCONT_BKP: row.USR_QTSERVCONT_BKP,
                CDTIPOSERV: row.CDTIPOSERV,
                CDCLIENTE: row.CDCLIENTE,
                NRPROPOSFAS: row.NRPROPOSFAS,
                NRVERPROPFAS: row.NRVERPROPFAS,
                SALDO: row.SALDO,
                QTSERVPEDC: row.QTSERVPEDC,
                NRSERVCONT: row.NRSERVCONT,
                BOTTONGRID: true,
                ROWNUM: row.ROWNUM,
            };
        }
    }

    public async exibirModalZerar() {
        this.ZerarModal = await ModalService.createFromJson('agendaServicos/modal/zerar_modal_agenda_servicos', true);
        this.ZerarModal.show();
    }

    public fecharModalZerar() {
        this.ZerarModal.hide();
        this.ZerarModal?.destroy();
    }

    public zerarSaldoDeHoras() {
        if (this.currentRow.BOTTONGRID === true) {
            const form = Metadata.getInstance<Form>('formZerarAgendaServicos');
            if (Utilities.validateForm(form)) {
                const grid = Metadata.getInstance<TekGrid>('tek-grid-agenda-servicos');
                const saldo = this.convertMinutes(this.currentRow.SALDO);
                const contratadas = this.convertMinutes(this.currentRow.QTSERVPEDC);
                let dataInput = Metadata.getInstance<Date>('formZerarAgendaServicos-USR_DTAGENDZERASALDO').value.split(' ')[0];
                dataInput = this.formataStringData(dataInput);
                const dsoperacao = `SALDO DE HORAS ALTERADO - Anterior: ${this.currentRow.SALDO} / Novo: 00:00`;
                const row = {
                    USR_QTSERVCONT_BKP: this.currentRow.USR_QTSERVCONT_BKP,
                    QTSERVPEDC: contratadas,
                    SALDO: saldo,
                    CDTIPOSERV: this.currentRow.CDTIPOSERV,
                    CDCLIENTE: this.currentRow.CDCLIENTE,
                    NRPROPOSFAS: this.currentRow.NRPROPOSFAS,
                    NRVERPROPFAS: this.currentRow.NRVERPROPFAS,
                    NRSERVCONT: this.currentRow.NRSERVCONT,
                    DSOPERACAO: dsoperacao,
                    ROWNUM: this.currentRow.ROWNUM,
                };
                LoadingService.show();
                Http.post('/zerarSaldoDeHoras', {
                    row,
                    USR_DTAGENDZERASALDO: dataInput,
                }).then(() => {
                    Utilities.showSuccessMessage();
                    grid.datasource.get();
                    this.fecharModalZerar();
                }).catch((error) => {
                    if (error.response.data.error === 'ERRO') {
                        Utilities.showDialogMessage('error', 'Operação bloqueada!', 'A data não pode ser inferior à data atual');
                    } else {
                        Utilities.showErrorMessage(error);
                    }
                }).finally(() => {
                    LoadingService.hide();
                });
            }
        } else {
            this.zerarSaldoDeHorasAction();
        }
    }

    public zerarSaldoDeHorasAction() {
        const form = Metadata.getInstance<Form>('formZerarAgendaServicos');
        let dataInput = Metadata.getInstance<Date>('formZerarAgendaServicos-USR_DTAGENDZERASALDO').value.split(' ')[0];
        dataInput = this.formataStringData(dataInput);
        if (Utilities.validateForm(form)) {
            const grid = Metadata.getInstance<TekGrid>('tek-grid-agenda-servicos');
            LoadingService.show();
            Http.post('/zerarSaldoDeHorasAction', {
                USR_DTAGENDZERASALDO: dataInput,
                row: grid.selectedRows,
            }).then(() => {
                Utilities.showSuccessMessage();
                grid.datasource.get();
                grid.selectedRows = [];
                this.fecharModalZerar();
            }).catch((error) => {
                if (error.response.data.error === 'ERRO') {
                    Utilities.showDialogMessage('error', 'Operação bloqueada!', 'A data não pode ser inferior à data atual');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public convertMinutes(hora: any) {
        const f0 = hora.split(':');
        const minutes = ((Number(f0[0]) * 60) + Number(f0[1]));
        const horas = minutes / 60;
        return horas;
    }

    public formataStringData(data: any) {
        const dia = data.split('/')[0];
        const mes = data.split('/')[1];
        const ano = data.split('/')[2];
        return `${(`0${dia}`).slice(-2)}-${(`0${mes}`).slice(-2)}-${ano}`;
    }

    public async abrirModalEditar({ row }: any) {
        await this.exibirModalEditar();
        Metadata.getInstance<TextInput>('formEditarAgendaServicos-SALDO').value = row.SALDO;
        this.currentRow = {
            USR_QTSERVCONT_BKP: row.USR_QTSERVCONT_BKP,
            CDTIPOSERV: row.CDTIPOSERV,
            CDCLIENTE: row.CDCLIENTE,
            NRPROPOSFAS: row.NRPROPOSFAS,
            NRVERPROPFAS: row.NRVERPROPFAS,
            SALDO: row.SALDO,
            QTSERVPEDC: row.QTSERVPEDC,
            QTHRSERVFATU: row.QTHRSERVFATU,
            NRSERVCONT: row.NRSERVCONT,
            ROWNUM: row.ROWNUM,
        };
    }

    public async exibirModalEditar() {
        this.EditarModal = await ModalService.createFromJson('agendaServicos/modal/editar_modal_agenda_servicos', true);
        this.EditarModal.show();
    }

    public fecharModalEditar() {
        this.EditarModal.hide();
        this.EditarModal?.destroy();
    }

    public editarSaldoDeHoras() {
        const form = Metadata.getInstance<Form>('formEditarAgendaServicos');
        if (Utilities.validateForm(form)) {
            const grid = Metadata.getInstance<TekGrid>('tek-grid-agenda-servicos');
            const saldo = this.convertMinutes(this.currentRow.SALDO);
            const string = Metadata.getInstance<TextInput>('formEditarAgendaServicos-NOVO_SALDO').value;
            const resultado = `${string.substr(0, 2)}:${string.substr(2, 2)}`;
            const novoSaldo = this.convertMinutes((resultado));
            const contratadas = this.convertMinutes(this.currentRow.QTSERVPEDC);
            let operacao = 0;
            let saldoEditado = 0;
            const dsoperacao = `SALDO DE HORAS ALTERADO - Anterior: ${this.currentRow.SALDO} / Novo: ${resultado}`;
            if (this.currentRow.QTHRSERVFATU === '00:00') {
                saldoEditado = novoSaldo;
            } else {
                operacao = (saldo - contratadas);
                saldoEditado = Math.abs(operacao) + novoSaldo;
            }
            const row = {
                USR_QTSERVCONT_BKP: this.currentRow.USR_QTSERVCONT_BKP,
                SALDO_EDITADO: saldoEditado,
                QTSERVPEDC: contratadas,
                CDTIPOSERV: this.currentRow.CDTIPOSERV,
                CDCLIENTE: this.currentRow.CDCLIENTE,
                NRPROPOSFAS: this.currentRow.NRPROPOSFAS,
                NRVERPROPFAS: this.currentRow.NRVERPROPFAS,
                DSOPERACAO: dsoperacao,
                NRSERVCONT: this.currentRow.NRSERVCONT,
                USR_DTAGENDZERASALDO: null,
                ROWNUM: this.currentRow.ROWNUM,
            };
            LoadingService.show();
            Http.post('/editarSaldoDeHoras', {
                row,
            }).then(() => {
                Utilities.showSuccessMessage();
                grid.datasource.get();
                this.fecharModalEditar();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmDialogReverterSaldo({ row }: any) {
        DialogService.show({
            name: 'warning_dialog',
            type: 'warning',
            title: 'Confirmação',
            text: 'Deseja realmente voltar a situação contratual inicial do saldo de horas?',
            buttons: [
                {
                    name: 'button-no',
                    component: 'ZdButton',
                    label: 'Não',
                    events: {
                        click: () => DialogService.hide(),
                    },
                    outline: true,
                },
                {
                    name: 'button-yes',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            LoadingService.show();
                            if (row) {
                                this.reverterSaldoHorasBotton(row);
                            } else {
                                this.reverterSaldoHorasAction();
                            }
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public converterSegundosFormato(segundos: any) {
        const h = segundos / 3600;
        const resto = segundos % 3600;
        const m = resto / 60;
        return `${h}:${m}`;
    }

    public reverterSaldoHorasBotton(rowGrid: any) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-agenda-servicos');
        const saldo = this.converterSegundosFormato(rowGrid.USR_QTSERVCONT_BKP * 3600);
        const dsoperacao = `SALDO DE HORAS ALTERADO - Anterior: ${rowGrid.SALDO} / Novo: ${saldo}`;
        const row = {
            USR_QTSERVCONT_BKP: rowGrid.USR_QTSERVCONT_BKP,
            CDTIPOSERV: rowGrid.CDTIPOSERV,
            CDCLIENTE: rowGrid.CDCLIENTE,
            NRPROPOSFAS: rowGrid.NRPROPOSFAS,
            NRVERPROPFAS: rowGrid.NRVERPROPFAS,
            NRSERVCONT: rowGrid.NRSERVCONT,
            DSOPERACAO: dsoperacao,
            ROWNUM: rowGrid.ROWNUM,
        };
        LoadingService.show();
        Http.post('/reverterSaldoHoras', {
            row,
        }).then(() => {
            Utilities.showSuccessMessage();
            grid.datasource.get();
        }).catch((error) => {
            if (error.response.data.error === 'ERRO') {
                Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Saldo já esta com o valor original contratado.');
            } else {
                Utilities.showErrorMessage(error);
            }
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public reverterSaldoHorasAction() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-agenda-servicos');
        LoadingService.show();
        Http.post('/reverterSaldoHorasAction', {
            row: grid.selectedRows,
        }).then(() => {
            Utilities.showSuccessMessage();
            grid.datasource.get();
            grid.selectedRows = [];
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public async abrirModalLog({ row }: any) {
        await this.exibirModalLog();
        const gridLog = Metadata.getInstance<TekGrid>('tek-grid-modal-log');
        gridLog.datasource.setFilter({
            CDPESQITEM: `${row.NRPROPOSFAS}${row.NRVERPROPFAS}${row.CDTIPOSERV.split('_')[1]}${row.NRSERVCONT}`,
        });
    }

    public async exibirModalLog() {
        this.LogModal = await ModalService.createFromJson('agendaServicos/modal/log_modal_agenda_servicos', true);
        this.LogModal.show();
    }

    public fecharModalLog() {
        this.LogModal.hide();
        this.LogModal?.destroy();
    }
}
