import { Utilities } from '@/util/Utilities';
import {
    DialogService,
    Form,
    LoadingService,
    Modal, ModalService, Select, Tabs, TextInput, Number,
} from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class Sm00006001TabelaPrecoServicoController {
    public tekgridTabelaPrecoVisivel: boolean = true;

    public currentRow: any = {};

    get formTabelaPrecoVisivel() {
        return !this.tekgridTabelaPrecoVisivel;
    }

    public voltarTekGridTabelaPrecoServico() {
        this.tekgridTabelaPrecoVisivel = true;
    }

    get textFrameTabelaPrecoServico() {
        return this.currentRow.DSPRECBASESERV;
    }

    public abrirFrameTabelaPrecoServicos({ row }: any) {
        this.tekgridTabelaPrecoVisivel = false;
        this.currentRow = row;
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        tabs.activeTab = 0;
        this.carregarDadosAbaTabelaPreco();
    }

    public carregarDadosAbaTabelaPreco() {
        Metadata.getInstance<TextInput>('formTabTabelaPreco-CDPRECBASESERV').value = this.currentRow.CDPRECBASESERV;
        Metadata.getInstance<TextInput>('formTabTabelaPreco-DSPRECBASESERV').value = this.currentRow.DSPRECBASESERV;
        Metadata.getInstance<Select>('formTabTabelaPreco-NRMOEDA').value = this.currentRow.NRMOEDA;
    }

    public verificaTabsTabelaPrecoServico() {
        const tabs = Metadata.getInstance<Tabs>('tabsInformation');
        const tabAtiva = tabs.activeTab;

        if (tabs.tabs[tabAtiva].name === 'tab_servicos') {
            this.carregarDadosAbaServicos();
        }
    }

    public carregarDadosAbaServicos() {
        const cdprecbaseserv = this.currentRow.CDPRECBASESERV;
        try {
            const grid = Metadata.getInstance<TekGrid>('tek-grid-tab-servicos');
            grid.datasource.setFilter({
                CDPRECBASESERV: cdprecbaseserv,
            });
        } catch (e) {
            // console.log(e);
        }
    }

    private modalAddTabPrec!: Modal;

    public async exibirModalAddTabPreco() {
        this.modalAddTabPrec = await ModalService.createFromJson('sm_00006_001_tabela_preco_servico/modal/sm_00006_001_modal_add_tabela_preco_servico', true);
        this.modalAddTabPrec.show();
    }

    public fecharModalAddTabPreco() {
        this.modalAddTabPrec.hide();
        this.modalAddTabPrec?.destroy();
    }

    public async abrirModalAddTabPreco() {
        await this.exibirModalAddTabPreco();
    }

    public insertTabelaPreco() {
        const form = Metadata.getInstance<Form>('formModalAddTabelaPreco');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tabela-preco-servico');
        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/salvarTabelaPreco', {
                CDPRECBASESERV: Metadata.getInstance<TextInput>('formModalAddTabelaPreco-CDPRECBASESERV').value,
                DSPRECBASESERV: Metadata.getInstance<TextInput>('formModalAddTabelaPreco-DSPRECBASESERV').value,
                NRMOEDA: Metadata.getInstance<Select>('formModalAddTabelaPreco-NRMOEDA').value,
            }).then(() => {
                this.fecharModalAddTabPreco();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public updateTabelaPreco() {
        const form = Metadata.getInstance<Form>('formTabTabelaPreco');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tabela-preco-servico');
        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/salvarTabelaPreco', {
                CDPRECBASESERV: Metadata.getInstance<TextInput>('formTabTabelaPreco-CDPRECBASESERV').value,
                DSPRECBASESERV: Metadata.getInstance<TextInput>('formTabTabelaPreco-DSPRECBASESERV').value,
                NRMOEDA: Metadata.getInstance<Select>('formTabTabelaPreco-NRMOEDA').value,
            }).then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
                this.voltarTekGridTabelaPrecoServico();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmDeleteMessage({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteTabelaPrecoServico();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteTabelaPrecoServico() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tabela-preco-servico');
        LoadingService.show();
        Http.post('/deleteTabelaPrecoServico', grid.selectedRows)
            .then(() => {
                grid.selectedRows = [];
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }

    private modalCopiaMoeda!: Modal;

    public async exibirModalCopiaMoeda() {
        this.modalCopiaMoeda = await ModalService.createFromJson('sm_00006_001_tabela_preco_servico/modal/sm_00006_001_modal_copia_moeda_tabela_preco_servico', true);
        this.modalCopiaMoeda.show();
    }

    public fecharModalCopiaMoeda() {
        this.modalCopiaMoeda.hide();
        this.modalCopiaMoeda?.destroy();
    }

    public async abrirModalCopiaMoeda() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tabela-preco-servico');
        if (grid.selectedRows.length === 0) {
            Utilities.showDialogMessage('error', 'Operação bloqueada!', 'É necessário selecionar um registro');
        } else {
            await this.exibirModalCopiaMoeda();
        }
    }

    public copiaOutraMoeda() {
        const form = Metadata.getInstance<Form>('formModalCopiaMoeda');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tabela-preco-servico');
        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/copiaOutraMoeda', {
                row: grid.selectedRows,
                NRMOEDA: Metadata.getInstance<Select>('formModalCopiaMoeda-NRMOEDA').value,
                NMMOEDA: Metadata.getInstance<Select>('formModalCopiaMoeda-NRMOEDA').selectValue.NMMOEDA,
                CONVERSAO: Metadata.getInstance<Number>('formModalCopiaMoeda-fatorConversao').value,
            }).then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
                this.fecharModalCopiaMoeda();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public visibilidadeTabsTablaPreco: boolean = true;

    public visibilidadeHeaderTablaPreco: boolean = true;

    public currentRowServicos: any = {};

    get gridTabMedidaVariavelVisibilidade() {
        return !this.visibilidadeTabsTablaPreco;
    }

    get textFrameServicoTabelaPrecoServico() {
        return this.currentRowServicos.NMSERVORCA;
    }

    public voltarTabsTabelaPrecoServico() {
        this.visibilidadeTabsTablaPreco = true;
        this.visibilidadeHeaderTablaPreco = true;
    }

    public abrirFrameMedidaVariavel({ row }: any) {
        this.visibilidadeTabsTablaPreco = false;
        this.visibilidadeHeaderTablaPreco = false;
        this.currentRowServicos = row;
        this.carregarDadosAbaMedidaVariavel();
    }

    public carregarDadosAbaMedidaVariavel() {
        const nrseqitprecbserv = this.currentRowServicos.NRSEQITPRECBSERV;
        try {
            const grid = Metadata.getInstance<TekGrid>('tek-grid-subtab-medida-variavel');
            grid.datasource.setFilter({
                NRSEQITPRECBSERV: nrseqitprecbserv,
            });
        } catch (e) {
            // console.log(e);
        }
    }

    private modalAddServico!: Modal;

    public async exibirModalAddServico() {
        this.modalAddServico = await ModalService.createFromJson('sm_00006_001_tabela_preco_servico/modal/sm_00006_001_modal_add_servico_tabela_preco_servico', true);
        this.modalAddServico.show();
    }

    public fecharmodalAddServico() {
        this.modalAddServico.hide();
        this.modalAddServico?.destroy();
    }

    public async abrirModalAddServico() {
        await this.exibirModalAddServico();
    }

    public validaServicoTabela() {
        const form = Metadata.getInstance<Form>('formModalAddServico');
        if (Utilities.validateForm(form)) {
            const servOrca = Metadata.getInstance<Select>('formModalAddServico-CDSERVORCA').value;
            const precBaseServ = this.currentRow.CDPRECBASESERV;
            const tipoMedida = Metadata.getInstance<Select>('formModalAddServico-CDTPMEDIDASERV').value;
            LoadingService.show();
            Http.post('/validaServicoTabela', {
                servOrca,
                precBaseServ,
                tipoMedida,
            }).then((response) => {
                if (response.data === false) {
                    this.salvarServicoTabela();
                } else {
                    Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Alguns dos serviços selecionados já estão inseridos para a medida informada.');
                }
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public salvarServicoTabela() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tab-servicos');
        Http.post('/salvarServicoTabela', [{
            NRSEQITPRECBSERV: null,
            CDPRECBASESERV: this.currentRow.CDPRECBASESERV,
            DTINIPBSERV: Metadata.getInstance<TextInput>('formModalAddServico-DTINIPBSERV').value,
            CDTPMEDIDASERV: Metadata.getInstance<Select>('formModalAddServico-CDTPMEDIDASERV').value,
            CDSERVORCA: Metadata.getInstance<Select>('formModalAddServico-CDSERVORCA').value,
            VRPRECO: Metadata.getInstance<Number>('formModalAddServico-VRPRECO').value,
            DTFIMVALPBSERV: Metadata.getInstance<TextInput>('formModalAddServico-DTFIMVALPBSERV').value,
        }]).then((response) => {
            grid.datasource.get();
            Utilities.showSuccessMessage();
            this.showConfirmMessageSincronizacao('I', response.data);
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public updateServicoTabela() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tab-servicos');
        const editedrows = grid.getEditedRows();
        LoadingService.show();
        Http.post('/salvarServicoTabela', editedrows)
            .then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
                this.showConfirmMessageSincronizacao('E', null);
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }

    public showConfirmMessageSincronizacao(tipo: any, data: any) {
        DialogService.show({
            name: 'buttons-dialog',
            type: 'warning',
            title: 'Sincronização',
            text: 'Deseja gerar as faixas de variação de preço automaticamente?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                            this.fecharmodalAddServico();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.sincronizarVariacaoPreco(tipo, data);
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public sincronizarVariacaoPreco(tipo: any, itprecBase = null) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tab-servicos');
        const gridMedidaVariavel = Metadata.getInstance<TekGrid>('tek-grid-subtab-medida-variavel');
        let nrSeqItPrecBServ = null;
        const arraynrSeqItPrecBServ: any = [];
        if (tipo === 'S') {
            gridMedidaVariavel.datasource.data.forEach((row) => {
                arraynrSeqItPrecBServ.push(row.NRSEQITPRECBSERV);
            });
            nrSeqItPrecBServ = arraynrSeqItPrecBServ;
        } else if (tipo === 'I') {
            nrSeqItPrecBServ = itprecBase;
        } else {
            grid.datasource.data.forEach((row) => {
                arraynrSeqItPrecBServ.push(row.NRSEQITPRECBSERV);
            });
            nrSeqItPrecBServ = arraynrSeqItPrecBServ;
        }
        Http.post('/sincronizarVariacaoPreco', {
            NRSEQITPRECBSERV: nrSeqItPrecBServ,
            TIPO: tipo,
        }).then(() => {
            grid.datasource.get();
            gridMedidaVariavel.datasource.get();
            Utilities.showSuccessMessage();
            this.fecharmodalAddServico();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public showConfirmDeleteMessageServicos({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteServicosTabelaPrecoServico();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteServicosTabelaPrecoServico() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tab-servicos');
        LoadingService.show();
        Http.post('/deleteServicosTabelaPrecoServico', grid.selectedRows)
            .then(() => {
                grid.selectedRows = [];
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }

    public showConfirmDialogSincronizar() {
        DialogService.show({
            name: 'warning_dialog',
            type: 'warning',
            title: 'Confirmação',
            text: 'Ao realizar a sincronização, as variações de preço atuais serão excluídas. Deseja realmente sincronizar as variações de preço?',
            buttons: [
                {
                    name: 'button-no',
                    component: 'ZdButton',
                    label: 'Não',
                    events: {
                        click: () => DialogService.hide(),
                    },
                    outline: true,
                },
                {
                    name: 'button-yes',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            LoadingService.show();
                            this.sincronizarVariacaoPreco('S', null);
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    private modalAddMedidaVariavel!: Modal;

    public async exibirModalAddMedidaVariavel() {
        this.modalAddMedidaVariavel = await ModalService.createFromJson('sm_00006_001_tabela_preco_servico/modal/sm_00006_001_modal_add_medida_variavel_tabela_preco_servico', true);
        this.modalAddMedidaVariavel.show();
    }

    public fecharmodalAddMedidaVariavel() {
        this.modalAddMedidaVariavel.hide();
        this.modalAddMedidaVariavel?.destroy();
    }

    public async abrirModalAddMedidaVariavel() {
        await this.exibirModalAddMedidaVariavel();
    }

    public validaFranquiaFaixaSave() {
        const form = Metadata.getInstance<Form>('formModalAddMedidaVariavel');
        if (Utilities.validateForm(form)) {
            LoadingService.show();
            Http.post('/validaFranquiaFaixa', {
                NRSEQITPRECBSERV: this.currentRowServicos.NRSEQITPRECBSERV,
                CDTPMEDIDASERV: this.currentRowServicos.CDTPMEDIDASERV,
                CDTPMEDIDAVARIAVEL: Metadata.getInstance<Select>('formModalAddMedidaVariavel-CDTPMEDIDASERV').value,
                QTFRANQUIA: Metadata.getInstance<TextInput>('formModalAddMedidaVariavel-QTFRANQUIA').value,
            }).then((response) => {
                console.warn(response);
                if (response.data.data[0].FAIXAS === 0) {
                    const params = {
                        CDTPMEDIDASERV: Metadata.getInstance<Select>('formModalAddMedidaVariavel-CDTPMEDIDASERV').value,
                        IDMULTIPVARIACAO: Metadata.getInstance<Select>('formModalAddMedidaVariavel-IDMULTIPVARIACAO').value,
                        QTFRANQUIA: Metadata.getInstance<TextInput>('formModalAddMedidaVariavel-QTFRANQUIA').value,
                    };
                    this.showConfirmMessageSincronizacaoMedida(params);
                } else {
                    Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Não é permitido definir uma franquia caso existam faixas de variação de preço as quais: O intervalo das quantidades de medida (De e Até) seja menor que a franquia.<br><br>- A franquia esteja dentro do intervalo das quantidades de medida (De e Até).');
                }
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmMessageSincronizacaoMedida(params: any) {
        DialogService.show({
            name: 'buttons-dialog',
            type: 'warning',
            title: 'Sincronização',
            text: 'Deseja gerar as faixas de variação de preço automaticamente?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                            this.inserevariacao(params, 'N');
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.inserevariacao(params, 'S');
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public inserevariacao(params: any, sincronizar: any) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-subtab-medida-variavel');
        LoadingService.show();
        Http.post('/insereVariacaoPreco', {
            NRSEQITPRECBSERV: this.currentRowServicos.NRSEQITPRECBSERV,
            CDTPMEDIDASERV: this.currentRowServicos.CDTPMEDIDASERV,
            CDTPMEDIDAVARIAVEL: params.CDTPMEDIDASERV,
            IDMULTIPVARIACAO: params.IDMULTIPVARIACAO,
            QTFRANQUIA: params.QTFRANQUIA,
            VRPRECOVARIACAO: this.currentRowServicos.VRPRECO,
            SINCRONIZAR: sincronizar,
            USAFRANQUIA: 'S',
        }).then(() => {
            grid.selectedRows = [];
            grid.datasource.get();
            Utilities.showSuccessMessage();
            this.fecharmodalAddMedidaVariavel();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public updateVariacao() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-subtab-medida-variavel');
        const editedrows = grid.getEditedRows();
        LoadingService.show();
        Http.post('/updateVariacao', {
            editedrows,
            CDTPMEDIDASERV: this.currentRowServicos.CDTPMEDIDASERV,
            NRSEQITPRECBSERV: this.currentRowServicos.NRSEQITPRECBSERV,
        })
            .then(() => {
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }

    public showConfirmDeleteMessageMedidaVariavel({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deleteServicosTabelaPrecoMedidaVariavel();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deleteServicosTabelaPrecoMedidaVariavel() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-subtab-medida-variavel');
        LoadingService.show();
        Http.post('/deleteServicosTabelaPrecoMedidaVariavel', grid.selectedRows)
            .then(() => {
                grid.selectedRows = [];
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
    }

    public visibilidadeTabsMedidaVariavel: boolean = true;

    public visibilidadeHeaderMedidaVariavel: boolean = true;

    public currentRowMedidaVariavel: any = {};

    public abrirFrameVariacaoPreco({ row }: any) {
        this.visibilidadeTabsMedidaVariavel = false;
        this.visibilidadeHeaderMedidaVariavel = false;
        this.currentRowMedidaVariavel = row;
        this.carregarDadosAbaVariacaoPreco();
    }

    public carregarDadosAbaVariacaoPreco() {
        const nrvariacaoprecbaseserv = this.currentRowMedidaVariavel.NRVARIACAOPRECBASESERV;
        try {
            const grid = Metadata.getInstance<TekGrid>('tek-grid-subtab-variacao-preco');
            grid.datasource.setFilter({
                NRVARIACAOPRECBASESERV: nrvariacaoprecbaseserv,
            });
        } catch (e) {
            // console.log(e);
        }
    }

    public voltarTabsMedidaVariavel() {
        this.visibilidadeTabsMedidaVariavel = true;
        this.visibilidadeHeaderMedidaVariavel = true;
    }

    get textFrameMedidaVariavelTabelaPrecoServico() {
        return this.currentRowMedidaVariavel.NMMEDIDAVAR;
    }

    get gridTabVariacaoPrecoVisibilidade() {
        return !this.visibilidadeTabsMedidaVariavel;
    }

    private modalAddVariacaoPreco!: Modal;

    public async exibirModalAddVariacaoPreco() {
        this.modalAddVariacaoPreco = await ModalService.createFromJson('sm_00006_001_tabela_preco_servico/modal/sm_00006_001_modal_add_variacao_preco_tabela_preco_servico', true);
        this.modalAddVariacaoPreco.show();
    }

    public fecharmodalAddVariacaoPreco() {
        this.modalAddVariacaoPreco.hide();
        this.modalAddVariacaoPreco?.destroy();
    }

    public async abrirModalAddVariacaoPreco() {
        await this.exibirModalAddVariacaoPreco();
    }

    public validaIntervaloQtMed() {
        const form = Metadata.getInstance<Form>('formModalAddVariacaoPreco');
        if (Utilities.validateForm(form)) {
            const qtMedidaIni = Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-QTMEDIDAINIVARIACAO').value;
            const qtMedidaFin = Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-QTMEDIDAFIMVARIACAO').value;
            if (qtMedidaIni > qtMedidaFin) {
                Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Quantidade da Medida - De não pode ser maior que "Quantidade da Medida - Até.');
            } else {
                this.validaTipoMedidaVariavel();
            }
        }
    }

    public validaTipoMedidaVariavel() {
        let inserir = 'S';
        const qtMedidaIniNew = Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-QTMEDIDAINIVARIACAO').value;
        const qtMedidaFinNew = Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-QTMEDIDAINIVARIACAO').value;
        LoadingService.show();
        Http.post('/validaTipoMedidaVariavel', {
            NRSEQITPRECBSERV: this.currentRowMedidaVariavel.NRSEQITPRECBSERV,
            CDTPMEDIDASERV: this.currentRowMedidaVariavel.CDTPMEDIDASERV,
            CDTPMEDIDAVARIAVEL: this.currentRowMedidaVariavel.CDTPMEDIDAVARIAVEL,
            NRVARIACAOPRECBASESERV: null,
        }).then((response) => {
            response.data.data.forEach((arrValida: any) => {
                const qtMedidaIniOld = arrValida.QTMEDIDAINIVARIACAO;
                const qtMedidaFinOld = arrValida.QTMEDIDAFIMVARIACAO;
                if (qtMedidaIniNew >= qtMedidaIniOld && qtMedidaIniNew <= qtMedidaFinOld) {
                    inserir = 'N';
                } else if (qtMedidaFinNew >= qtMedidaIniOld && qtMedidaFinNew <= qtMedidaFinOld) {
                    inserir = 'N';
                } else if (qtMedidaIniNew <= qtMedidaIniOld && qtMedidaFinNew >= qtMedidaFinOld) {
                    inserir = 'N';
                }
            });
            if (inserir === 'S') {
                this.salvarVariacaoTipoDeMedida();
            } else {
                Utilities.showDialogMessage('error', 'Operação bloqueada!', 'Já existe uma variação cadastrada para o Tipo de Medida para Variação e para o intervalo de Quantidade da Medida informados.');
            }
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public salvarVariacaoTipoDeMedida() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-subtab-variacao-preco');
        LoadingService.show();
        Http.post('/salvarVariacaoTipoDeMedida', {
            NRSEQITPRECBSERV: this.currentRowMedidaVariavel.NRSEQITPRECBSERV,
            CDTPMEDIDASERV: this.currentRowMedidaVariavel.CDTPMEDIDASERV,
            CDTPMEDIDAVARIAVEL: this.currentRowMedidaVariavel.CDTPMEDIDAVARIAVEL,
            IDMULTIPVARIACAO: this.currentRowMedidaVariavel.IDMULTIPVARIACAO,
            QTFRANQUIA: this.currentRowMedidaVariavel.QTFRANQUIA,
            QTMEDIDAINIVARIACAO: Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-QTMEDIDAINIVARIACAO').value,
            QTMEDIDAFIMVARIACAO: Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-QTMEDIDAFIMVARIACAO').value,
            VRPRECOVARIACAO: Metadata.getInstance<Number>('formModalAddVariacaoPreco-VRPRECOVARIACAO').value,
            DTINIPBSERV: Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-DTINIPBSERV').value,
            DTFIMVALPBSERV: Metadata.getInstance<TextInput>('formModalAddVariacaoPreco-DTFIMVALPBSERV').value,
        }).then(() => {
            grid.selectedRows = [];
            grid.datasource.get();
            Utilities.showSuccessMessage();
            this.fecharmodalAddVariacaoPreco();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
